.. This README is meant for consumption by humans and pypi. Pypi can render rst files so please do not use Sphinx features.
   If you want to learn more about writing documentation, please check out: http://docs.plone.org/about/documentation_styleguide.html
   This text does not appear on pypi or github. It is a comment.

==============
imioweb.policy
==============

Fait la glue entre différentes dépendences et passe parfois des paramètres. La liste des dépendences se trouve dans setup.py Quand on installe le module imioweb.policy dans plone, celui-ci va se charger d'installer d'autres modules à son tour.

.. image:: https://travis-ci.com/IMIO/imioweb.policy.svg?branch=master
    :target: https://travis-ci.com/IMIO/imioweb.policy

.. image:: https://coveralls.io/repos/github/IMIO/imioweb.policy/badge.svg?branch=master
    :target: https://coveralls.io/github/IMIO/imioweb.policy?branch=master

Features
--------

- à compléter


Examples
--------

- à compléter


Documentation
-------------

- à commpléter


Translations
------------

- à compléter


Installation
------------

Install imioweb.policy by adding it to your buildout::

    [buildout]

    ...

    eggs =
        imioweb.policy


and then running ``bin/buildout``


Contribute
----------

- Issue Tracker: https://github.com/collective/imioweb.policy/issues
- Source Code: https://github.com/collective/imioweb.policy
- Documentation: https://docs.plone.org/foo/bar


Support
-------

If you are having issues, please let us know.
We have a mailing list located at: project@example.com


License
-------

The project is licensed under the GPLv2.
